/*
 * Header for functions common to all programs.
 *
 * Copyright 2014, 2021, 2023 Andrew Wood.
 *
 * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
 */

#ifndef COMMON_H
#define COMMON_H 1

#ifndef _STDINT_H
#include <stdint.h>
#endif	/* _STDINT_H */

#define COPYRIGHT_NOTICE "Copyright 2014, 2021, 2023 Andrew Wood"
#define LICENSE_NOTICE "License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>"
#define FREE_SOFTWARE_NOTICE "This is free software: you are free to change and redistribute it."
#define WARRANTY_NOTICE "There is NO WARRANTY, to the extent permitted by law."

#define ENABLE_SETPROCTITLE 1

#define _(x) x

typedef int_fast8_t flag_t;

extern flag_t debugging_enabled;	 /* global flag to enable debugging */
extern flag_t using_syslog;		 /* global flag to report to syslog */
extern char *common_program_name;	 /* set this to program leafname */
extern int error_count;			 /* global error counter from error() */

#if ENABLE_DEBUGGING
void debug(const char *, ...);
#else				/* ENABLE_DEBUGGING */
#define debug(x,...)
#endif				/* ENABLE_DEBUGGING */
void error(const char *, ...);
void die(const char *, ...);

int ds_leafname_pos(char *pathname);
char *ds_leafname(char *pathname);
int ds_tmpfile(char *pathname, char **tmpnameptr);


#if ENABLE_SETPROCTITLE
void initproctitle(int, char **);
void setproctitle(const char *, ...);
#else				/* ENABLE_SETPROCTITLE */
#define initproctitle(x,y)
#define setproctitle(x,...)
#endif				/* ENABLE_SETPROCTITLE */
char *xstrdup(const char *);
void create_parent_dirs(const char *);

#endif	/* COMMON_H */

/* EOF */
